#!/usr/bin/env node
'use strict';

var _commander = require('commander');

var _commander2 = _interopRequireDefault(_commander);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _package = require('../package.json');

var _package2 = _interopRequireDefault(_package);

var _command = require('./command');

var _command2 = _interopRequireDefault(_command);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

_commander2.default.version(_package2.default.version);

_commander2.default.command('teams').alias('t').on('--help', () => {
  console.log('');
  console.log(`  List teams ordered by HLTV.org rank.`);
  console.log(`  You can choose a team to get the following information:`);
  console.log('');
  console.log(`  - Players info`);
  console.log(`  - Map win statistics`);
  console.log(`  - Recent results`);
  console.log('');
  console.log('  Example:');
  console.log(`           ${_chalk2.default`{hex('#66ff66') cs-go teams} => List teams by HLTV.org rank`}`);
  console.log('');
  console.log(`  For more detailed information, check the GitHub page: ${_chalk2.default`{hex('#66ff66') https://github.com/lucaspalencia/cs-go}`}`);
}).action(() => {
  _command2.default.teams();
});

_commander2.default.command('matches').alias('m').on('--help', () => {
  console.log('');
  console.log(`  List live/next matches by HLTV.org.`);
  console.log(`  You can choose a game to get the following information:`);
  console.log('');
  console.log(`  - Event / Format / Team players`);
  console.log(`  - Vetoes`);
  console.log(`  - Maps results`);
  console.log(`  - Streams`);
  console.log(`  - Last head to head matches`);
  console.log('');
  console.log('  Example:');
  console.log(`           ${_chalk2.default`{hex('#66ff66') cs-go matches} => List live/next matches by HLTV.org`}`);
  console.log('');
  console.log(`  For more detailed information, check the GitHub page: ${_chalk2.default`{hex('#66ff66') https://github.com/lucaspalencia/cs-go}`}`);
}).action(() => {
  _command2.default.matches();
});

_commander2.default.command('results').alias('r').option('-l, --limit <limit>', 'Show last results').on('--help', () => {
  console.log('');
  console.log(`  Show the last matches results from HLTV.org`);
  console.log(`  You can choose a limit of matches by set -l option`);
  console.log('');
  console.log('  Example:');
  console.log(`           ${_chalk2.default`{hex('#66ff66') cs-go results}       => List the last 20 matches results by HLTV.org`}`);
  console.log(`           ${_chalk2.default`{hex('#66ff66') cs-go results -l 30} => List last 30 matches results by HLTV.org`}`);
  console.log('');
  console.log(`  For more detailed information, check the GitHub page: ${_chalk2.default`{hex('#66ff66') https://github.com/lucaspalencia/cs-go}`}`);
}).action(option => {
  let limit = option.limit;

  if (!limit) {
    limit = 20;
  }

  if (limit > 100) {
    limit = 100;
  }

  _command2.default.results(limit);
});

_commander2.default.command('streams').alias('s').on('--help', () => {
  console.log('');
  console.log(`  Show live streams from HLTV.org`);
  console.log('');
  console.log('  Example:');
  console.log(`           ${_chalk2.default`{hex('#66ff66') cs-go streams}       => List live streams by HLTV.org`}`);
  console.log('');
  console.log(`  For more detailed information, check the GitHub page: ${_chalk2.default`{hex('#66ff66') https://github.com/lucaspalencia/cs-go}`}`);
}).action(option => {
  _command2.default.streams();
});

_commander2.default.on('--help', () => {
  console.log('');
  console.log('');
  console.log(`  Welcome to ${_chalk2.default`{bold.hex('#F59E5B') CS-GO}`}!`);
  console.log('');
  console.log(`  Wanna check information about CS:GO teams please enter: ${_chalk2.default`{hex('#66ff66') cs-go teams}`}`);
  console.log(`  Wanna check CS:GO live/next matches please enter: ${_chalk2.default`{hex('#66ff66') cs-go matches}`}`);
  console.log(`  Wanna check CS:GO last matches results please enter: ${_chalk2.default`{hex('#66ff66') cs-go results}`}`);
  console.log(`  Wanna check CS:GO live streams please enter: ${_chalk2.default`{hex('#66ff66') cs-go streams}`}`);
  console.log('');
  console.log(`  For more detailed information, check the GitHub page: ${_chalk2.default`{hex('#66ff66') https://github.com/lucaspalencia/cs-go}`}`);
  console.log(`  Or enter ${_chalk2.default`{hex('#66ff66') cs-go teams -h, cs-go matches -h, cs-go results -h, cs-go streams -h}`} to get more information`);
});

_commander2.default.option('-v --version', _package2.default.version);

_commander2.default.command('*').action(command => {
  console.log(`${_chalk2.default.red.bold('Unknown command:')} ${_chalk2.default.white.bold(command)}`);
  process.exit(1);
});

if (process.argv.length === 2) _commander2.default.help();

_commander2.default.parse(process.argv);