'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _hltv = require('hltv');

var _hltv2 = _interopRequireDefault(_hltv);

var _ora = require('ora');

var _ora2 = _interopRequireDefault(_ora);

var _inquirer = require('inquirer');

var _inquirer2 = _interopRequireDefault(_inquirer);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _stringz = require('stringz');

var _wideAlign = require('wide-align');

var _cfonts = require('../../utils/cfonts');

var _cfonts2 = _interopRequireDefault(_cfonts);

var _date = require('../../utils/date');

var _date2 = _interopRequireDefault(_date);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; }

const MAX_WIDTH = 132;
const TEAMNAME_WIDTH = 45;
const EVENT_WIDTH = 60;
const STATUS_WIDTH = 19;

const formatStatus = (date, live) => {
  let questionStatus = _chalk2.default.green.bold('LIVE');

  if (!live) {
    questionStatus = (0, _date2.default)(date);
  }

  return _chalk2.default.yellow.bold(questionStatus);
};

const formatQuestionName = (team1, team2, event, date, status) => {
  let teamsName = `${team1.name} vs ${team2.name}`;
  let questionStatus = formatStatus(date, status);
  let question = `|⌘${(0, _wideAlign.center)(teamsName, TEAMNAME_WIDTH)} |${(0, _wideAlign.center)(_chalk2.default.bold(event.name), EVENT_WIDTH)} | ${(0, _wideAlign.center)(questionStatus, STATUS_WIDTH)} |`;

  return question;
};

const matchesList = (() => {
  var _ref = _asyncToGenerator(function* () {
    console.log('');
    const spinner = (0, _ora2.default)('Loading live/next matches').start();

    let matches = yield _hltv2.default.getMatches();

    spinner.stop();

    const header = `│ ${(0, _wideAlign.center)(_chalk2.default`{bold.blue Teams}`, TEAMNAME_WIDTH)} │${(0, _wideAlign.center)(_chalk2.default`{bold.blue Event}`, EVENT_WIDTH)} │ ${(0, _wideAlign.center)(_chalk2.default`{bold.blue Status}`, STATUS_WIDTH)} |`;

    const questions = [{
      name: 'match',
      message: 'Which game do you want to see?',
      type: 'list',
      pageSize: 45,
      choices: [new _inquirer2.default.Separator(`${(0, _stringz.limit)('', MAX_WIDTH, '─')}`), new _inquirer2.default.Separator(header), new _inquirer2.default.Separator(`${(0, _stringz.limit)('', MAX_WIDTH, '─')}`)]
    }];

    const last = matches.length - 1;

    (0, _cfonts2.default)('Matches');

    matches.forEach(function (match, index) {
      const id = match.id,
            team1 = match.team1,
            team2 = match.team2,
            event = match.event,
            date = match.date,
            live = match.live;


      if ((date || live) && team1 && team2) {
        questions[0].choices.push({
          name: formatQuestionName(team1, team2, event, date, live),
          value: id
        });

        if (index !== last) {
          questions[0].choices.push(new _inquirer2.default.Separator(`${(0, _stringz.limit)('', MAX_WIDTH, '-')}`));
        } else {
          questions[0].choices.push(new _inquirer2.default.Separator(`${(0, _stringz.limit)('', MAX_WIDTH, '─')}`));
        }
      }
    });

    const answer = yield _inquirer2.default.prompt(questions);

    return answer;
  });

  return function matchesList() {
    return _ref.apply(this, arguments);
  };
})();

exports.default = matchesList;