'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _hltv = require('hltv');

var _hltv2 = _interopRequireDefault(_hltv);

var _inquirer = require('inquirer');

var _inquirer2 = _interopRequireDefault(_inquirer);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _ora = require('ora');

var _ora2 = _interopRequireDefault(_ora);

var _cfonts = require('../../utils/cfonts');

var _cfonts2 = _interopRequireDefault(_cfonts);

var _stringz = require('stringz');

var _wideAlign = require('wide-align');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; }

const MAX_WIDTH = 60;
const TEAMNAME_WIDTH = 20;
const RANK_WIDTH = 11;
const POINTS_WIDTH = 20;

const formatQuestionName = (name, place, points) => {
  let question = `|⌘${(0, _wideAlign.center)(name, TEAMNAME_WIDTH)} |${(0, _wideAlign.center)(place.toString(), RANK_WIDTH)} | ${(0, _wideAlign.center)(points.toString(), POINTS_WIDTH)} |`;

  switch (place) {
    case 1:
      {
        question = `|⌘${(0, _wideAlign.center)(_chalk2.default.yellow.bold(name), TEAMNAME_WIDTH)} |${(0, _wideAlign.center)(_chalk2.default.yellow.bold(place.toString()), RANK_WIDTH)} | ${(0, _wideAlign.center)(_chalk2.default.yellow.bold(points.toString()), POINTS_WIDTH)} |`;
        break;
      }

    case 2:
      {
        question = `|⌘${(0, _wideAlign.center)(_chalk2.default.cyan.bold(name), TEAMNAME_WIDTH)} |${(0, _wideAlign.center)(_chalk2.default.cyan.bold(place.toString()), RANK_WIDTH)} | ${(0, _wideAlign.center)(_chalk2.default.cyan.bold(points.toString()), POINTS_WIDTH)} |`;
        break;
      }

    case 3:
      {
        question = `|⌘${(0, _wideAlign.center)(_chalk2.default.magenta.bold(name), TEAMNAME_WIDTH)} |${(0, _wideAlign.center)(_chalk2.default.magenta.bold(place.toString()), RANK_WIDTH)} | ${(0, _wideAlign.center)(_chalk2.default.magenta.bold(points.toString()), POINTS_WIDTH)} |`;
        break;
      }
  }

  return question;
};

const teamsList = (() => {
  var _ref = _asyncToGenerator(function* () {
    console.log('');
    const spinner = (0, _ora2.default)('Loading teams').start();

    let teams = yield _hltv2.default.getTeamRanking();

    spinner.stop();

    const header = `│ ${(0, _wideAlign.center)(_chalk2.default`{bold.blue Team}`, TEAMNAME_WIDTH)} │ ${(0, _wideAlign.center)(_chalk2.default`{bold.blue Rank}`, RANK_WIDTH)}│ ${(0, _wideAlign.center)(_chalk2.default`{bold.blue Points}`, POINTS_WIDTH)} │`;

    const questions = [{
      name: 'team',
      message: 'Which team do you want to get info?',
      type: 'list',
      pageSize: 45,
      choices: [new _inquirer2.default.Separator(`${(0, _stringz.limit)('', MAX_WIDTH, '─')}`), new _inquirer2.default.Separator(header), new _inquirer2.default.Separator(`${(0, _stringz.limit)('', MAX_WIDTH, '─')}`)]
    }];

    const last = teams.length - 1;

    (0, _cfonts2.default)('by HLTV.org');

    teams.forEach(function (teamInfo, index) {
      const team = teamInfo.team,
            place = teamInfo.place,
            points = teamInfo.points;


      questions[0].choices.push({
        name: formatQuestionName(team.name, place, points),
        value: team.id
      });

      if (index !== last) {
        questions[0].choices.push(new _inquirer2.default.Separator(`${(0, _stringz.limit)('', MAX_WIDTH, '-')}`));
      } else {
        questions[0].choices.push(new _inquirer2.default.Separator(`${(0, _stringz.limit)('', MAX_WIDTH, '─')}`));
      }
    });

    const answer = yield _inquirer2.default.prompt(questions);

    return answer;
  });

  return function teamsList() {
    return _ref.apply(this, arguments);
  };
})();

exports.default = teamsList;